<?php

namespace Schaffen\Fiscal\FiscalDocument\Models;

use Illuminate\Database\Eloquent\Model;
use Schaffen\Fiscal\FiscalDocument\Models\TelecomServiceFiscalNoteItem;

class TelecomServiceFiscalNote extends Model
{

    protected $useValidateRules = true;
    protected $rules = [
        'nfst_fk_pes_codigo' => 'required|integer',
        'nfst_cpf_cnpj' => 'required|string|max:15',
        'nfst_ie' => 'required|string|max:15',
        'nfst_razao_social' => 'required|string|max:80',
        'nfst_telefone_contato' => 'required|string|max:15',
        'nfst_end_cep' => 'required|string|max:10',
        'nfst_end_logradouro' => 'required|string|max:80',
        'nfst_end_numero' => 'required|string|max:10',
        'nfst_end_bairro' => 'required|string|max:80',
        'nfst_end_complemento' => 'string|max:80',
        'nfst_end_cidade' => 'required|string|max:80',
        'nfst_end_uf' => 'required',
        'nfst_classe_consumo' => 'required|integer',
        'nfst_fase_ou_tipo_utilizacao' => 'required|integer',
        'nfst_grupo_tensao' => 'required|integer',
        'nfst_cod_id_consumidor_assinante' => 'required|string|max:12',
        'nfst_data_emissao' => 'required|string|max:8',
        'nfst_modelo' => 'required|numeric',
        'nfst_serie' => 'required|string|max:3',
        'nfst_numero' => 'required|numeric',
        'nfst_codigo_autenticacao_digital' => 'required|string|max:32',
        'nfst_valor_total' => 'required|numeric',
        'nfst_bc_icms' => 'required|numeric',
        'nfst_icms_destacado' => 'required|numeric',
        'nfst_op_isentas' => 'required|numeric',
        'nfst_outros_valores' => 'required|numeric',
        'nfst_situacao_documento' => 'required',
        'nfst_informacao_adicional' => 'string|max:30',
        'nfst_ano_mes_referencia' => 'required|string|max:4',
        'nfst_ref_item_nf' => 'required|numeric',
        'nfst_nro_terminal_ou_uc' => 'required|string|max:12',
        'nfst_tipo_pessoa' => 'required|integer',
        'nfst_tipo_cliente' => 'required|numeric',
        'nfst_subclasse_consumo' => 'required|numeric',
        'nfst_nro_terminal_principal' => 'required|string|max:12',
        'nfst_cnpj_emitente' => 'required|string|max:14',
        'nfst_nro_fat_comercial' => 'required|numeric',
        'nfst_valor_total_fat_comercial' => 'required|numeric',
        'nfst_data_leitura_anterior' => 'required|string|max:8',
        'nfst_data_leitura_atual' => 'required|string|max:8',
        'nfst_codigo_aut_digital' => 'required|string|max:32',
        'nfst_data_aut_digital' => 'required|string|max:8',
        'nfst_observacao' => 'string|max:50',
        'nfst_usu_insert' => 'required|string|max:80',
        'nfst_usu_update' => 'string|max:80',
        'nfst_fk_nfsta_codigo' => 'integer',
    ];

    protected $validationMessages = [
        'nfst_fk_pes_codigo.required' => "O campo 'fk pes codigo' é obrigatório.",
        'nfst_fk_pes_codigo.integer' => "O formato do campo 'fk pes codigo' é inválido (informar número inteiro).",
        'nfst_cpf_cnpj.required' => "O campo 'cpf cnpj' é obrigatório.",
        'nfst_cpf_cnpj.max' => "O campo 'cpf cnpj' excede o tamanho máximo de 15 caracteres.",
        'nfst_ie.required' => "O campo 'ie' é obrigatório.",
        'nfst_ie.max' => "O campo 'ie' excede o tamanho máximo de 15 caracteres.",
        'nfst_razao_social.required' => "O campo 'razao social' é obrigatório.",
        'nfst_razao_social.max' => "O campo 'razao social' excede o tamanho máximo de 80 caracteres.",
        'nfst_telefone_contato.required' => "O campo 'telefone contato' é obrigatório.",
        'nfst_telefone_contato.max' => "O campo 'telefone contato' excede o tamanho máximo de 15 caracteres.",
        'nfst_end_cep.required' => "O campo 'end cep' é obrigatório.",
        'nfst_end_cep.max' => "O campo 'end cep' excede o tamanho máximo de 10 caracteres.",
        'nfst_end_logradouro.required' => "O campo 'end logradouro' é obrigatório.",
        'nfst_end_logradouro.max' => "O campo 'end logradouro' excede o tamanho máximo de 80 caracteres.",
        'nfst_end_numero.required' => "O campo 'end numero' é obrigatório.",
        'nfst_end_numero.max' => "O campo 'end numero' excede o tamanho máximo de 10 caracteres.",
        'nfst_end_bairro.required' => "O campo 'end bairro' é obrigatório.",
        'nfst_end_bairro.max' => "O campo 'end bairro' excede o tamanho máximo de 80 caracteres.",
        'nfst_end_complemento.max' => "O campo 'end complemento' excede o tamanho máximo de 80 caracteres.",
        'nfst_end_cidade.required' => "O campo 'end cidade' é obrigatório.",
        'nfst_end_cidade.max' => "O campo 'end cidade' excede o tamanho máximo de 80 caracteres.",
        'nfst_end_uf.required' => "O campo 'end uf' é obrigatório.",
        'nfst_classe_consumo.required' => "O campo 'classe consumo' é obrigatório.",
        'nfst_classe_consumo.integer' => "O formato do campo 'classe consumo' é inválido (informar número inteiro).",
        'nfst_fase_ou_tipo_utilizacao.required' => "O campo 'fase ou tipo utilizacao' é obrigatório.",
        'nfst_fase_ou_tipo_utilizacao.integer' => "O formato do campo 'fase ou tipo utilizacao' é inválido (informar número inteiro).",
        'nfst_grupo_tensao.required' => "O campo 'grupo tensao' é obrigatório.",
        'nfst_grupo_tensao.integer' => "O formato do campo 'grupo tensao' é inválido (informar número inteiro).",
        'nfst_cod_id_consumidor_assinante.required' => "O campo 'cod id consumidor assinante' é obrigatório.",
        'nfst_cod_id_consumidor_assinante.max' => "O campo 'cod id consumidor assinante' excede o tamanho máximo de 12 caracteres.",
        'nfst_data_emissao.required' => "O campo 'data emissao' é obrigatório.",
        'nfst_data_emissao.max' => "O campo 'data emissao' excede o tamanho máximo de 8 caracteres.",
        'nfst_modelo.required' => "O campo 'modelo' é obrigatório.",
        'nfst_modelo.numeric' => "O formato do campo 'modelo' é inválido (informar apenas números).",
        'nfst_serie.required' => "O campo 'serie' é obrigatório.",
        'nfst_serie.max' => "O campo 'serie' excede o tamanho máximo de 3 caracteres.",
        'nfst_numero.required' => "O campo 'numero' é obrigatório.",
        'nfst_numero.numeric' => "O formato do campo 'numero' é inválido (informar apenas números).",
        'nfst_codigo_autenticacao_digital.required' => "O campo 'codigo autenticacao digital' é obrigatório.",
        'nfst_codigo_autenticacao_digital.max' => "O campo 'codigo autenticacao digital' excede o tamanho máximo de 32 caracteres.",
        'nfst_valor_total.required' => "O campo 'valor total' é obrigatório.",
        'nfst_valor_total.numeric' => "O formato do campo 'valor total' é inválido (informar apenas números).",
        'nfst_bc_icms.required' => "O campo 'bc icms' é obrigatório.",
        'nfst_bc_icms.numeric' => "O formato do campo 'bc icms' é inválido (informar apenas números).",
        'nfst_icms_destacado.required' => "O campo 'icms destacado' é obrigatório.",
        'nfst_icms_destacado.numeric' => "O formato do campo 'icms destacado' é inválido (informar apenas números).",
        'nfst_op_isentas.required' => "O campo 'op isentas' é obrigatório.",
        'nfst_op_isentas.numeric' => "O formato do campo 'op isentas' é inválido (informar apenas números).",
        'nfst_outros_valores.required' => "O campo 'outros valores' é obrigatório.",
        'nfst_outros_valores.numeric' => "O formato do campo 'outros valores' é inválido (informar apenas números).",
        'nfst_situacao_documento.required' => "O campo 'situacao documento' é obrigatório.",
        'nfst_informacao_adicional.max' => "O campo 'informacao adicional' excede o tamanho máximo de 30 caracteres.",
        'nfst_ano_mes_referencia.required' => "O campo 'ano mes referencia' é obrigatório.",
        'nfst_ano_mes_referencia.max' => "O campo 'ano mes referencia' excede o tamanho máximo de 4 caracteres.",
        'nfst_ref_item_nf.required' => "O campo 'ref item nf' é obrigatório.",
        'nfst_ref_item_nf.numeric' => "O formato do campo 'ref item nf' é inválido (informar apenas números).",
        'nfst_nro_terminal_ou_uc.required' => "O campo 'nro terminal ou uc' é obrigatório.",
        'nfst_nro_terminal_ou_uc.max' => "O campo 'nro terminal ou uc' excede o tamanho máximo de 12 caracteres.",
        'nfst_tipo_pessoa.required' => "O campo 'tipo pessoa' é obrigatório.",
        'nfst_tipo_pessoa.integer' => "O formato do campo 'tipo pessoa' é inválido (informar número inteiro).",
        'nfst_tipo_cliente.required' => "O campo 'tipo cliente' é obrigatório.",
        'nfst_tipo_cliente.numeric' => "O formato do campo 'tipo cliente' é inválido (informar apenas números).",
        'nfst_subclasse_consumo.required' => "O campo 'subclasse consumo' é obrigatório.",
        'nfst_subclasse_consumo.numeric' => "O formato do campo 'subclasse consumo' é inválido (informar apenas números).",
        'nfst_nro_terminal_principal.required' => "O campo 'nro terminal principal' é obrigatório.",
        'nfst_nro_terminal_principal.max' => "O campo 'nro terminal principal' excede o tamanho máximo de 12 caracteres.",
        'nfst_cnpj_emitente.required' => "O campo 'cnpj emitente' é obrigatório.",
        'nfst_cnpj_emitente.max' => "O campo 'cnpj emitente' excede o tamanho máximo de 14 caracteres.",
        'nfst_nro_fat_comercial.required' => "O campo 'nro fat comercial' é obrigatório.",
        'nfst_nro_fat_comercial.numeric' => "O formato do campo 'nro fat comercial' é inválido (informar apenas números).",
        'nfst_valor_total_fat_comercial.required' => "O campo 'valor total fat comercial' é obrigatório.",
        'nfst_valor_total_fat_comercial.numeric' => "O formato do campo 'nro valor total fat comercial' é inválido (informar apenas números).",
        'nfst_data_leitura_anterior.required' => "O campo 'data leitura anterior' é obrigatório.",
        'nfst_data_leitura_anterior.max' => "O campo 'data leitura anterior' excede o tamanho máximo de 8 caracteres.",
        'nfst_data_leitura_atual.required' => "O campo 'data leitura atual' é obrigatório.",
        'nfst_data_leitura_atual.max' => "O campo 'data leitura atual' excede o tamanho máximo de 8 caracteres.",
        'nfst_codigo_aut_digital.required' => "O campo 'codigo aut digital' é obrigatório.",
        'nfst_codigo_aut_digital.max' => "O campo 'codigo aut digital' excede o tamanho máximo de 32 caracteres.",
        'nfst_data_aut_digital.required' => "O campo 'data aut digital' é obrigatório.",
        'nfst_data_aut_digital.max' => "O campo 'data aut digital' excede o tamanho máximo de 8 caracteres.",
        'nfst_observacao.max' => "O campo 'observacao' excede o tamanho máximo de 50 caracteres.",
        'nfst_usu_insert.required' => "O campo 'usu insert' é obrigatório.",
        'nfst_usu_insert.max' => "O campo 'usu insert' excede o tamanho máximo de 80 caracteres.",
        'nfst_usu_update.max' => "O campo 'usu update' excede o tamanho máximo de 80 caracteres."
    ];

    protected $table = "fiscal.nota_fiscal_servico_telecom";
    protected $primaryKey = "nfst_codigo";
    protected $fillable = [
        "nfst_fk_pes_codigo","nfst_cpf_cnpj","nfst_ie","nfst_razao_social",
        "nfst_telefone_contato","nfst_end_cep","nfst_end_logradouro","nfst_end_numero",
        "nfst_end_bairro","nfst_end_complemento","nfst_end_cidade","nfst_end_uf",
        "nfst_classe_consumo","nfst_fase_ou_tipo_utilizacao","nfst_grupo_tensao",
        "nfst_cod_id_consumidor_assinante","nfst_data_emissao","nfst_modelo",
        "nfst_serie","nfst_numero","nfst_codigo_autenticacao_digital","nfst_valor_total",
        "nfst_bc_icms","nfst_icms_destacado","nfst_op_isentas","nfst_outros_valores",
        "nfst_situacao_documento","nfst_informacao_adicional","nfst_ano_mes_referencia",
        "nfst_ref_item_nf","nfst_nro_terminal_ou_uc","nfst_tipo_pessoa","nfst_tipo_cliente",
        "nfst_subclasse_consumo","nfst_nro_terminal_principal", "nfst_uf_terminal", "nfst_cnpj_emitente",
        "nfst_nro_fat_comercial","nfst_valor_total_fat_comercial","nfst_data_leitura_anterior",
        "nfst_data_leitura_atual","nfst_codigo_aut_digital","nfst_data_aut_digital","nfst_observacao",
        "nfst_usu_insert","nfst_usu_update","nfst_fk_nfsta_codigo"
    ];
    const CREATED_AT = "nfst_date_insert";
    const CREATED_BY = "nfst_user_insert";
    const UPDATED_AT = "nfst_date_update";
    const UPDATED_BY = "nfst_user_update";

    protected $with = [
        'services'
    ];   

    public function services()
    {
        return $this->hasMany(TelecomServiceFiscalNoteItem::class, 'nfsti_fk_nfst_codigo');
    }

}